**To delete a proxy session**

The following ``delete-proxy-session`` example deletes the specified proxy session. ::

    aws chime delete-proxy-session \
        --voice-connector-id abcdef1ghij2klmno3pqr4 \
        --proxy-session-id 123a4bc5-67d8-901e-2f3g-h4ghjk56789l

This command produces no output.

For more information, see `Proxy Phone Sessions <https://docs.aws.amazon.com/chime/latest/dg/proxy-phone-sessions.html>`__ in the *Amazon Chime Developer Guide*.
